==> bonita-server-7.5.0-sources.jar: org/bonitasoft/engine/persistence/SBonitaReadException.java <==
/**
 * Copyright (C) 2015 BonitaSoft S.A.
 * BonitaSoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.persistence;

import org.bonitasoft.engine.commons.exceptions.SBonitaException;

/**
 * @author Charles Souillard
 */
public class SBonitaReadException extends SBonitaException {

    private static final long serialVersionUID = 1L;

    private final AbstractSelectDescriptor<?> selectDescriptor;

    public SBonitaReadException(final Throwable cause, final AbstractSelectDescriptor<?> selectDescriptor) {
        super(cause);
        this.selectDescriptor = selectDescriptor;
    }

    public SBonitaReadException(final String message, final Throwable cause, final AbstractSelectDescriptor<?> selectDescriptor) {
        super(message, cause);
        this.selectDescriptor = selectDescriptor;
    }

    public SBonitaReadException(final String message) {
        super(message);
        selectDescriptor = null;
    }

    public SBonitaReadException(final Throwable cause) {
        super(cause);
        selectDescriptor = null;
    }

    public SBonitaReadException(final String message, final Throwable cause) {
        super(message, cause);
        selectDescriptor = null;
    }

    public AbstractSelectDescriptor<?> getSelectDescriptor() {
        return selectDescriptor;
    }

}

==> bonita-server-10.0.0-sources.jar: org/bonitasoft/engine/persistence/SBonitaReadException.java <==
/**
 * Copyright (C) 2019 Bonitasoft S.A.
 * Bonitasoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.persistence;

import org.bonitasoft.engine.commons.exceptions.SBonitaException;

/**
 * @author Charles Souillard
 */
public class SBonitaReadException extends SBonitaException {

    private static final long serialVersionUID = 1L;

    private final AbstractSelectDescriptor<?> selectDescriptor;

    public SBonitaReadException(final Throwable cause, final AbstractSelectDescriptor<?> selectDescriptor) {
        super(cause);
        this.selectDescriptor = selectDescriptor;
    }

    public SBonitaReadException(final String message, final Throwable cause,
            final AbstractSelectDescriptor<?> selectDescriptor) {
        super(message, cause);
        this.selectDescriptor = selectDescriptor;
    }

    public SBonitaReadException(final String message) {
        super(message);
        selectDescriptor = null;
    }

    public SBonitaReadException(final Throwable cause) {
        super(cause);
        selectDescriptor = null;
    }

    public SBonitaReadException(final String message, final Throwable cause) {
        super(message, cause);
        selectDescriptor = null;
    }

    public AbstractSelectDescriptor<?> getSelectDescriptor() {
        return selectDescriptor;
    }

}
